## 0.4.0 - 2023-04-01

### Fixed

- Changed import so it will work in production.

## 0.3.0 - 2023-03-28

### Fixed

- Removed unnecessary files from package build.

## 0.2.0 - 2023-03-28

### Fixed

- Added dependencies list. Basically, the toml package that is needed for this
project.

## 0.1.0 - 2023-03-27

### Added

- Released version 0.1.
